@@ -6,7 +6,9 @@
     :copyright: 2007 by Armin Ronacher.
     :license: BSD, see LICENSE for more details.
 """
+from py.test import raises
 from jinja2 import Environment, DictLoader, contextfunction
+from jinja2.exceptions import TemplateAssertionError
 
 templates = {
     'master.html': '<title>{{ page_title|default(_("missing")) }}</title>'
@@ -66,6 +68,14 @@ def test_trans_plural():
     assert tmpl.render(LANGUAGE='de', user_count=2) == '2 Benutzer online'
 
 
+def test_complex_plural():
+    tmpl = i18n_env.from_string('{% trans foo=42, count=2 %}{{ count }} item{% '
+                                'pluralize count %}{{ count }} items{% endtrans %}')
+    assert tmpl.render() == '2 items'
+    raises(TemplateAssertionError, i18n_env.from_string,
+           '{% trans foo %}...{% pluralize bar %}...{% endtrans %}')
+
+
 def test_trans_stringformatting():
     tmpl = i18n_env.get_template('stringformat.html')
     assert tmpl.render(LANGUAGE='de', user_count=5) == 'Benutzer: 5'
