@@ -8,45 +8,35 @@
 """
 
 SIMPLE = '''\
-{% macro say_hello name %}Hello {{ name }}!{% endmacro %}
+{% macro say_hello(name) %}Hello {{ name }}!{% endmacro %}
 {{ say_hello('Peter') }}\
 '''
 
-KWARGSFAILURE = '''\
-{% macro foo bar %}...{% endmacro %}
-{{ foo(bar='blub') }}\
-'''
-
 SCOPING = '''\
-{% macro level1 data1 %}
-{% macro level2 data2 %}{{ data1 }}|{{ data2 }}{% endmacro %}
+{% macro level1(data1) %}
+{% macro level2(data2) %}{{ data1 }}|{{ data2 }}{% endmacro %}
 {{ level2('bar') }}{% endmacro %}
-{{ level1('foo') }}|{{ level2('bar') }}\
+{{ level1('foo') }}\
 '''
 
 ARGUMENTS = '''\
-{% macro m a, b, c='c', d='d' %}{{ a }}|{{ b }}|{{ c }}|{{ d }}{% endmacro %}
+{% macro m(a, b, c='c', d='d') %}{{ a }}|{{ b }}|{{ c }}|{{ d }}{% endmacro %}
 {{ m() }}|{{ m('a') }}|{{ m('a', 'b') }}|{{ m(1, 2, 3) }}\
 '''
 
-PARENTHESES = '''\
-{% macro foo(a, b) %}{{ a }}|{{ b }}{% endmacro %}\
-{{ foo(1, 2) }}\
-'''
-
 VARARGS = '''\
-{% macro test %}{{ varargs|join('|') }}{% endmacro %}\
+{% macro test() %}{{ varargs|join('|') }}{% endmacro %}\
 {{ test(1, 2, 3) }}\
 '''
 
 SIMPLECALL = '''\
-{% macro test %}[[{{ caller() }}]]{% endmacro %}\
+{% macro test() %}[[{{ caller() }}]]{% endmacro %}\
 {% call test() %}data{% endcall %}\
 '''
 
 COMPLEXCALL = '''\
-{% macro test %}[[{{ caller(data='data') }}]]{% endmacro %}\
-{% call test() %}{{ data }}{% endcall %}\
+{% macro test() %}[[{{ caller('data') }}]]{% endmacro %}\
+{% call(data) test() %}{{ data }}{% endcall %}\
 '''
 
 CALLERUNDEFINED = '''\
@@ -63,20 +53,9 @@ def test_simple(env):
     assert tmpl.render() == 'Hello Peter!'
 
 
-def test_kwargs_failure(env):
-    from jinja.exceptions import TemplateRuntimeError
-    tmpl = env.from_string(KWARGSFAILURE)
-    try:
-        tmpl.render()
-    except TemplateRuntimeError, e:
-        pass
-    else:
-        raise AssertionError('kwargs failure test failed')
-
-
 def test_scoping(env):
     tmpl = env.from_string(SCOPING)
-    assert tmpl.render() == 'foo|bar|'
+    assert tmpl.render() == 'foo|bar'
 
 
 def test_arguments(env):
@@ -84,11 +63,6 @@ def test_arguments(env):
     assert tmpl.render() == '||c|d|a||c|d|a|b|c|d|1|2|3|d'
 
 
-def test_parentheses(env):
-    tmpl = env.from_string(PARENTHESES)
-    assert tmpl.render() == '1|2'
-
-
 def test_varargs(env):
     tmpl = env.from_string(VARARGS)
     assert tmpl.render() == '1|2|3'
@@ -110,5 +84,23 @@ def test_caller_undefined(env):
 
 
 def test_include(env):
-    tmpl = env.from_string('{% include "include" %}{{ test("foo") }}')
+    tmpl = env.from_string('{% from "include" import test %}{{ test("foo") }}')
     assert tmpl.render() == '[foo]'
+
+
+def test_macro_api(env):
+    tmpl = env.from_string('{% macro foo(a, b) %}{% endmacro %}'
+                           '{% macro bar() %}{{ varargs }}{{ kwargs }}{% endmacro %}'
+                           '{% macro baz() %}{{ caller() }}{% endmacro %}')
+    assert tmpl.module.foo.arguments == ('a', 'b')
+    assert tmpl.module.foo.defaults == ()
+    assert tmpl.module.foo.name == 'foo'
+    assert not tmpl.module.foo.caller
+    assert not tmpl.module.foo.catch_kwargs
+    assert not tmpl.module.foo.catch_varargs
+    assert tmpl.module.bar.arguments == ()
+    assert tmpl.module.bar.defaults == ()
+    assert not tmpl.module.bar.caller
+    assert tmpl.module.bar.catch_kwargs
+    assert tmpl.module.bar.catch_varargs
+    assert tmpl.module.baz.caller
